@@ -8,6 +8,7 @@
 
 #include <QAbstractItemModel>
 #include <QObject>
+
 class MatrixManager;
 class MatrixRoomsModel;
 class MatrixRoomsSortProxyModel;
@@ -16,6 +17,7 @@ class MatrixRoomsSortProxyModel;
 class MatrixController : public QObject
 {
     Q_OBJECT
+
     /** Matrix support is built in at all? */
     Q_PROPERTY(bool isAvailable READ isAvailable CONSTANT)
     Q_PROPERTY(QObject *manager READ manager CONSTANT)
@@ -28,7 +30,7 @@ public:
 
     static bool isAvailable();
 
-    QObject *manager() const;
+    [[nodiscard]] QObject *manager() const;
     QAbstractItemModel *roomsModel();
 
 private:
