@@ -5,6 +5,7 @@
 #define MATRIXBEACON_H
 
 #include <QObject>
+#include <qqmlregistration.h>
 
 #include <Quotient/connection.h>
 
@@ -16,6 +17,8 @@
 class MatrixBeacon : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+
     Q_PROPERTY(Quotient::Connection *connection READ connection WRITE setConnection NOTIFY connectionChanged)
     Q_PROPERTY(QString roomId READ roomId WRITE setRoomId NOTIFY roomIdChanged)
     Q_PROPERTY(bool isActive READ isActive NOTIFY activeChanged)
